@@ -2,5 +2,5 @@ var _ogre_texture_unit_state_8h =
 [
     [ "Ogre::Sampler::UVWAddressingMode", "struct_ogre_1_1_sampler_1_1_u_v_w_addressing_mode.html", "struct_ogre_1_1_sampler_1_1_u_v_w_addressing_mode" ],
     [ "Ogre::TextureUnitState::TextureEffect", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect.html", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect" ],
-    [ "SamplerPtr", "_ogre_texture_unit_state_8h.html#ga34843c20652d796e4e3aab70dc1786c3", null ]
+    [ "Ogre::SamplerPtr", "group___materials.html#ga34843c20652d796e4e3aab70dc1786c3", null ]
 ];
\ No newline at end of file
