@@ -285,20 +285,20 @@ var annotated_dup =
       [ "IOException", "class_ogre_1_1_i_o_exception.html", "class_ogre_1_1_i_o_exception" ],
       [ "IShader", "struct_ogre_1_1_i_shader.html", "struct_ogre_1_1_i_shader" ],
       [ "isPodLike", "struct_ogre_1_1is_pod_like.html", "struct_ogre_1_1is_pod_like" ],
-      [ "isPodLike< bool >", "struct_ogre_1_1is_pod_like_3_01bool_01_4.html", "struct_ogre_1_1is_pod_like_3_01bool_01_4" ],
-      [ "isPodLike< char >", "struct_ogre_1_1is_pod_like_3_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01char_01_4" ],
-      [ "isPodLike< double >", "struct_ogre_1_1is_pod_like_3_01double_01_4.html", "struct_ogre_1_1is_pod_like_3_01double_01_4" ],
-      [ "isPodLike< float >", "struct_ogre_1_1is_pod_like_3_01float_01_4.html", "struct_ogre_1_1is_pod_like_3_01float_01_4" ],
-      [ "isPodLike< int >", "struct_ogre_1_1is_pod_like_3_01int_01_4.html", "struct_ogre_1_1is_pod_like_3_01int_01_4" ],
-      [ "isPodLike< long >", "struct_ogre_1_1is_pod_like_3_01long_01_4.html", "struct_ogre_1_1is_pod_like_3_01long_01_4" ],
-      [ "isPodLike< short >", "struct_ogre_1_1is_pod_like_3_01short_01_4.html", "struct_ogre_1_1is_pod_like_3_01short_01_4" ],
-      [ "isPodLike< signed char >", "struct_ogre_1_1is_pod_like_3_01signed_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01signed_01char_01_4" ],
-      [ "isPodLike< std::pair< T, U > >", "struct_ogre_1_1is_pod_like_3_01std_1_1pair_3_01_t_00_01_u_01_4_01_4.html", "struct_ogre_1_1is_pod_like_3_01std_1_1pair_3_01_t_00_01_u_01_4_01_4" ],
-      [ "isPodLike< T * >", "struct_ogre_1_1is_pod_like_3_01_t_01_5_01_4.html", "struct_ogre_1_1is_pod_like_3_01_t_01_5_01_4" ],
-      [ "isPodLike< unsigned >", "struct_ogre_1_1is_pod_like_3_01unsigned_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01_4" ],
-      [ "isPodLike< unsigned char >", "struct_ogre_1_1is_pod_like_3_01unsigned_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01char_01_4" ],
-      [ "isPodLike< unsigned long >", "struct_ogre_1_1is_pod_like_3_01unsigned_01long_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01long_01_4" ],
-      [ "isPodLike< unsigned short >", "struct_ogre_1_1is_pod_like_3_01unsigned_01short_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01short_01_4" ],
+      [ "isPodLike&lt; bool &gt;", "struct_ogre_1_1is_pod_like_3_01bool_01_4.html", "struct_ogre_1_1is_pod_like_3_01bool_01_4" ],
+      [ "isPodLike&lt; char &gt;", "struct_ogre_1_1is_pod_like_3_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01char_01_4" ],
+      [ "isPodLike&lt; double &gt;", "struct_ogre_1_1is_pod_like_3_01double_01_4.html", "struct_ogre_1_1is_pod_like_3_01double_01_4" ],
+      [ "isPodLike&lt; float &gt;", "struct_ogre_1_1is_pod_like_3_01float_01_4.html", "struct_ogre_1_1is_pod_like_3_01float_01_4" ],
+      [ "isPodLike&lt; int &gt;", "struct_ogre_1_1is_pod_like_3_01int_01_4.html", "struct_ogre_1_1is_pod_like_3_01int_01_4" ],
+      [ "isPodLike&lt; long &gt;", "struct_ogre_1_1is_pod_like_3_01long_01_4.html", "struct_ogre_1_1is_pod_like_3_01long_01_4" ],
+      [ "isPodLike&lt; short &gt;", "struct_ogre_1_1is_pod_like_3_01short_01_4.html", "struct_ogre_1_1is_pod_like_3_01short_01_4" ],
+      [ "isPodLike&lt; signed char &gt;", "struct_ogre_1_1is_pod_like_3_01signed_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01signed_01char_01_4" ],
+      [ "isPodLike&lt; std::pair&lt; T, U &gt; &gt;", "struct_ogre_1_1is_pod_like_3_01std_1_1pair_3_01_t_00_01_u_01_4_01_4.html", "struct_ogre_1_1is_pod_like_3_01std_1_1pair_3_01_t_00_01_u_01_4_01_4" ],
+      [ "isPodLike&lt; T * &gt;", "struct_ogre_1_1is_pod_like_3_01_t_01_5_01_4.html", "struct_ogre_1_1is_pod_like_3_01_t_01_5_01_4" ],
+      [ "isPodLike&lt; unsigned &gt;", "struct_ogre_1_1is_pod_like_3_01unsigned_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01_4" ],
+      [ "isPodLike&lt; unsigned char &gt;", "struct_ogre_1_1is_pod_like_3_01unsigned_01char_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01char_01_4" ],
+      [ "isPodLike&lt; unsigned long &gt;", "struct_ogre_1_1is_pod_like_3_01unsigned_01long_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01long_01_4" ],
+      [ "isPodLike&lt; unsigned short &gt;", "struct_ogre_1_1is_pod_like_3_01unsigned_01short_01_4.html", "struct_ogre_1_1is_pod_like_3_01unsigned_01short_01_4" ],
       [ "ItemIdentityException", "class_ogre_1_1_item_identity_exception.html", "class_ogre_1_1_item_identity_exception" ],
       [ "IteratorWrapper", "class_ogre_1_1_iterator_wrapper.html", "class_ogre_1_1_iterator_wrapper" ],
       [ "KeyFrame", "class_ogre_1_1_key_frame.html", "class_ogre_1_1_key_frame" ],
@@ -539,7 +539,7 @@ var annotated_dup =
       [ "SimplePageContentCollection", "class_ogre_1_1_simple_page_content_collection.html", "class_ogre_1_1_simple_page_content_collection" ],
       [ "SimplePageContentCollectionFactory", "class_ogre_1_1_simple_page_content_collection_factory.html", "class_ogre_1_1_simple_page_content_collection_factory" ],
       [ "SimpleParamCommand", "class_ogre_1_1_simple_param_command.html", "class_ogre_1_1_simple_param_command" ],
-      [ "SimpleParamCommand< _Class, const String &, getter, setter >", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4" ],
+      [ "SimpleParamCommand&lt; _Class, const String &amp;, getter, setter &gt;", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4" ],
       [ "SimpleRenderable", "class_ogre_1_1_simple_renderable.html", "class_ogre_1_1_simple_renderable" ],
       [ "SimpleSpline", "class_ogre_1_1_simple_spline.html", "class_ogre_1_1_simple_spline" ],
       [ "Singleton", "class_ogre_1_1_singleton.html", "class_ogre_1_1_singleton" ],
@@ -548,11 +548,11 @@ var annotated_dup =
       [ "SkeletonManager", "class_ogre_1_1_skeleton_manager.html", "class_ogre_1_1_skeleton_manager" ],
       [ "SkeletonSerializer", "class_ogre_1_1_skeleton_serializer.html", "class_ogre_1_1_skeleton_serializer" ],
       [ "SmallVector", "class_ogre_1_1_small_vector.html", "class_ogre_1_1_small_vector" ],
-      [ "SmallVector< T, 0 >", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4.html", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4" ],
+      [ "SmallVector&lt; T, 0 &gt;", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4.html", "class_ogre_1_1_small_vector_3_01_t_00_010_01_4" ],
       [ "SmallVectorBase", "class_ogre_1_1_small_vector_base.html", "class_ogre_1_1_small_vector_base" ],
       [ "SmallVectorImpl", "class_ogre_1_1_small_vector_impl.html", "class_ogre_1_1_small_vector_impl" ],
       [ "SmallVectorTemplateBase", "class_ogre_1_1_small_vector_template_base.html", "class_ogre_1_1_small_vector_template_base" ],
-      [ "SmallVectorTemplateBase< T, true >", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4" ],
+      [ "SmallVectorTemplateBase&lt; T, true &gt;", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html", "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4" ],
       [ "SmallVectorTemplateCommon", "class_ogre_1_1_small_vector_template_common.html", "class_ogre_1_1_small_vector_template_common" ],
       [ "SPFMDeleteT", "struct_ogre_1_1_s_p_f_m_delete_t.html", "struct_ogre_1_1_s_p_f_m_delete_t" ],
       [ "SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", "struct_ogre_1_1_s_p_f_m_none" ],
@@ -607,9 +607,9 @@ var annotated_dup =
       [ "Vector", "class_ogre_1_1_vector.html", "class_ogre_1_1_vector" ],
       [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
       [ "VectorBase", "struct_ogre_1_1_vector_base.html", "struct_ogre_1_1_vector_base" ],
-      [ "VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4" ],
-      [ "VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4" ],
-      [ "VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4" ],
+      [ "VectorBase&lt; 2, Real &gt;", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4" ],
+      [ "VectorBase&lt; 3, Real &gt;", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4" ],
+      [ "VectorBase&lt; 4, Real &gt;", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4" ],
       [ "VectorIterator", "class_ogre_1_1_vector_iterator.html", "class_ogre_1_1_vector_iterator" ],
       [ "VectorIteratorWrapper", "class_ogre_1_1_vector_iterator_wrapper.html", "class_ogre_1_1_vector_iterator_wrapper" ],
       [ "VectorSet", "struct_ogre_1_1_vector_set.html", "struct_ogre_1_1_vector_set" ],
