@@ -4,6 +4,7 @@ var class_ogre_1_1_auto_param_data_source =
     [ "setCurrentRenderable", "class_ogre_1_1_auto_param_data_source.html#a012ceb6b159c4d81e9b63170f235e63f", null ],
     [ "setWorldMatrices", "class_ogre_1_1_auto_param_data_source.html#ae65d20f572488b5bff84f095b0850783", null ],
     [ "setCurrentCamera", "class_ogre_1_1_auto_param_data_source.html#a0c71d0f089723307c8329f28f0ddc228", null ],
+    [ "setCameraArray", "class_ogre_1_1_auto_param_data_source.html#a449463ded816f13ccde02a794d5aeff1", null ],
     [ "setCurrentLightList", "class_ogre_1_1_auto_param_data_source.html#afac03642ad3286b4f7f7afca616b4acb", null ],
     [ "setTextureProjector", "class_ogre_1_1_auto_param_data_source.html#a0191611c98b4a46328b5610a53a77781", null ],
     [ "setCurrentRenderTarget", "class_ogre_1_1_auto_param_data_source.html#a8c59386216c2a61d34ce48195cc5a319", null ],
@@ -20,9 +21,12 @@ var class_ogre_1_1_auto_param_data_source =
     [ "getBoneMatrixCount", "class_ogre_1_1_auto_param_data_source.html#a3abc7f04e2b4891e4a5e831f8912dcf0", null ],
     [ "getWorldMatrixCount", "class_ogre_1_1_auto_param_data_source.html#a8ae6715c657ad1bf2483102aec8f9281", null ],
     [ "getViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a8402e87412505edf845510081ab0008e", null ],
+    [ "getViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a6b7ddc68ac1e1bda0dce281ccb5ce2a1", null ],
     [ "getViewProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a20da1d44783a1f3454bf34671aed328e", null ],
     [ "getProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#a0aed6b631a2965082888a298af83ca52", null ],
+    [ "getProjectionMatrix", "class_ogre_1_1_auto_param_data_source.html#ab6191abc4f9811318ac2fb166d17471b", null ],
     [ "getWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a9b3d1e3e28114671174b90b54bf1de76", null ],
+    [ "getWorldViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a2b176605da2fc03fe2c62e52b252d063", null ],
     [ "getWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#aad2fb1df270848f191ee987d7174dc91", null ],
     [ "getInverseWorldMatrix", "class_ogre_1_1_auto_param_data_source.html#a389304ad714617d6fb1c56d6302bd8e4", null ],
     [ "getInverseWorldViewMatrix", "class_ogre_1_1_auto_param_data_source.html#a547eeceff510f5816ada49077e336a22", null ],
@@ -77,6 +81,7 @@ var class_ogre_1_1_auto_param_data_source =
     [ "getShadowExtrusionDistance", "class_ogre_1_1_auto_param_data_source.html#a666f1089d83b0da3d223157ef72390b9", null ],
     [ "getSceneDepthRange", "class_ogre_1_1_auto_param_data_source.html#ad37c94d86c7128ebc9e1f000eb3ef332", null ],
     [ "getShadowSceneDepthRange", "class_ogre_1_1_auto_param_data_source.html#ace31465a839948a9c08f67049e2059a1", null ],
+    [ "setShadowColour", "class_ogre_1_1_auto_param_data_source.html#a7da9209eabc44a6a28a3bbe9d788a425", null ],
     [ "getShadowColour", "class_ogre_1_1_auto_param_data_source.html#a48aadefcfa972ace170d3415b3dcfa92", null ],
     [ "getInverseViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#af881e8166923f6aa80c5f73c9d207da2", null ],
     [ "getInverseTransposeViewProjMatrix", "class_ogre_1_1_auto_param_data_source.html#a0246b52c319c20e0f95f9f385f188180", null ],
