@@ -7,9 +7,11 @@ var class_ogre_1_1_script_compiler =
     [ "compile", "class_ogre_1_1_script_compiler.html#ab2bff7a6427fde76c9cf9137d4eaeac5", null ],
     [ "compile", "class_ogre_1_1_script_compiler.html#a3f68dccf295d809da7b12f2583f16504", null ],
     [ "addError", "class_ogre_1_1_script_compiler.html#a4b2fd2d22e4e0cd7874aa93263618d5f", null ],
+    [ "addError", "class_ogre_1_1_script_compiler.html#ad1dc96ce6c66049cdd171466de641701", null ],
     [ "setListener", "class_ogre_1_1_script_compiler.html#ad3e0810f50a23557927a3e61c6c4341f", null ],
     [ "getListener", "class_ogre_1_1_script_compiler.html#a45f15b394990297eba618606b7aea567", null ],
     [ "getResourceGroup", "class_ogre_1_1_script_compiler.html#a1ebabc7e113f013f00bebd6d4d3e6df7", null ],
+    [ "getFileName", "class_ogre_1_1_script_compiler.html#ab7a423c038246ef3abd9d6fbec3300cd", null ],
     [ "_fireEvent", "class_ogre_1_1_script_compiler.html#a7fb900872c1c8e6a114b742f5d74438b", null ],
     [ "registerCustomWordId", "class_ogre_1_1_script_compiler.html#a21710f3b93e73c61b0f625b819e4b15d", null ],
     [ "AbstractTreeBuilder", "class_ogre_1_1_script_compiler.html#adcb97289c0c7a163b6e38e00f1adfd2b", null ],
