@@ -8,7 +8,8 @@ var group___bullet =
       [ "CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html#a1a0a90916e7a319c950c52c7f02bfc43", null ],
       [ "~CollisionWorld", "class_ogre_1_1_bullet_1_1_collision_world.html#a440552b57ebd041ca89164053ed24f8b", null ],
       [ "addCollisionObject", "class_ogre_1_1_bullet_1_1_collision_world.html#aa1b97dfab12428da4b447c0f3ae59967", null ],
-      [ "rayTest", "class_ogre_1_1_bullet_1_1_collision_world.html#a289c5df44c8ed32c6c519d57ad6a1b6f", null ]
+      [ "rayTest", "class_ogre_1_1_bullet_1_1_collision_world.html#a289c5df44c8ed32c6c519d57ad6a1b6f", null ],
+      [ "attachCollisionObject", "class_ogre_1_1_bullet_1_1_collision_world.html#aca5597475dc1e63e63956ba1e838e981", null ]
     ] ],
     [ "Ogre::Bullet::DebugDrawer", "class_ogre_1_1_bullet_1_1_debug_drawer.html", [
       [ "DebugDrawer", "class_ogre_1_1_bullet_1_1_debug_drawer.html#a590e3e215f6c7f48788d13b0e0f5128a", null ],
@@ -25,8 +26,23 @@ var group___bullet =
       [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a7e72c8cb32eff9d058447ea7198f65ef", null ],
       [ "DynamicsWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a54d4cbf8c35c17149c7287ad4d05b88e", null ],
       [ "addRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#afcafa5a4a6ba86014b0a1273d9584e25", null ],
+      [ "addKinematicRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a53dda17a683b2479bcafa648de21a83d", null ],
+      [ "addTerrainRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a5066d5a46b870aa2f32a9d08e41f0849", null ],
+      [ "addTerrainRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#ad00959b1e06a3b50217dbeac38d5221c", null ],
+      [ "attachRigidBody", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a60bbbb6fcd6f563c412710772e49f296", null ],
       [ "getBtWorld", "class_ogre_1_1_bullet_1_1_dynamics_world.html#a3ef0f4b137145278b7901ac79cebaac6", null ]
     ] ],
+    [ "Ogre::Bullet::HeightFieldData", "struct_ogre_1_1_bullet_1_1_height_field_data.html", [
+      [ "bodyPosition", "struct_ogre_1_1_bullet_1_1_height_field_data.html#a257c833d6d9e346794452786bb52cd2c", null ],
+      [ "terrainHeights", "struct_ogre_1_1_bullet_1_1_height_field_data.html#acd3ff117ec933f22bd5f0f2ddd3e71d7", null ]
+    ] ],
+    [ "Ogre::Bullet::KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html", [
+      [ "KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html#af32aa1ea36d15e0351fa1c9420a21c9d", null ],
+      [ "~KinematicMotionSimple", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html#a43d56a3290d8019948727c77f2091ba0", null ],
+      [ "recoverFromPenetration", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html#afb7cdeb0f819b3829b484aa2cd3675af", null ],
+      [ "updateAction", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html#a9353ea509b21156c91a975ba954f145c", null ],
+      [ "debugDraw", "class_ogre_1_1_bullet_1_1_kinematic_motion_simple.html#a4c5e4e3f6ff742582a356583a7ad8db1", null ]
+    ] ],
     [ "Ogre::Bullet::RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html", [
       [ "~RayResultCallback", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a59e08ca9b439889c9d103d8bdc3e96c8", null ],
       [ "addSingleResult", "struct_ogre_1_1_bullet_1_1_ray_result_callback.html#a0f521584d3810e3339d886f6c26cae83", null ]
@@ -42,7 +58,8 @@ var group___bullet =
       [ "Ogre::Bullet::CT_CYLINDER", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6e2834b721b1bf5444d685379e6a1031", null ],
       [ "Ogre::Bullet::CT_CAPSULE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a073e87fdfdfabb19755f1defcbe1bb78", null ],
       [ "Ogre::Bullet::CT_TRIMESH", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a4c72346edc69af82d8ee74e32f0f19d9", null ],
-      [ "Ogre::Bullet::CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ]
+      [ "Ogre::Bullet::CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ],
+      [ "Ogre::Bullet::CT_COMPOUND", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a93188a275f493576a9744fa6738198f8", null ]
     ] ],
     [ "Ogre::Bullet::convert", "group___bullet.html#gae507a0bfafc7f585d0270d7445767065", null ],
     [ "Ogre::Bullet::convert", "group___bullet.html#ga6e488b2065b2f2daea503cfb2d7b7c0a", null ],
@@ -51,5 +68,9 @@ var group___bullet =
     [ "Ogre::Bullet::createSphereCollider", "group___bullet.html#ga4816ec507132c27c52b40dab60c6ba87", null ],
     [ "Ogre::Bullet::createBoxCollider", "group___bullet.html#ga508ce5259dc72353adaf458c9a1165bd", null ],
     [ "Ogre::Bullet::createCapsuleCollider", "group___bullet.html#ga4f6fa3c86ab9ac184a2149768002991d", null ],
-    [ "Ogre::Bullet::createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ]
+    [ "Ogre::Bullet::createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ],
+    [ "Ogre::Bullet::createTrimeshCollider", "group___bullet.html#gaed45b1c7e0ab58c9a0126671ab47c5cc", null ],
+    [ "Ogre::Bullet::createConvexHullCollider", "group___bullet.html#ga4b0184ec77d0e75daaf8e55fd8b90965", null ],
+    [ "Ogre::Bullet::createCompoundShape", "group___bullet.html#gab62b4f5293ae739167b3b22688d53b27", null ],
+    [ "Ogre::Bullet::createHeightfieldTerrainShape", "group___bullet.html#ga4f8524c5a233db7cae27d5b9bc90db05", null ]
 ];
\ No newline at end of file
