@@ -1,6 +1,6 @@
 var group___general =
 [
-    [ "Ogre::AlignedAllocator< T, Alignment >", "struct_ogre_1_1_aligned_allocator.html", [
+    [ "Ogre::AlignedAllocator&lt; T, Alignment &gt;", "struct_ogre_1_1_aligned_allocator.html", [
       [ "rebind", "struct_ogre_1_1_aligned_allocator_1_1rebind.html", [
         [ "other", "struct_ogre_1_1_aligned_allocator_1_1rebind.html#ae2157f23d51da7c107f7a37e95dec785", null ]
       ] ],
@@ -204,7 +204,7 @@ var group___general =
     [ "Ogre::ExceptionFactory", "class_ogre_1_1_exception_factory.html", [
       [ "throwException", "class_ogre_1_1_exception_factory.html#aef2ce54e5447655284bc67fc7692a4b9", null ]
     ] ],
-    [ "Ogre::FactoryObj< T >", "class_ogre_1_1_factory_obj.html", [
+    [ "Ogre::FactoryObj&lt; T &gt;", "class_ogre_1_1_factory_obj.html", [
       [ "~FactoryObj", "class_ogre_1_1_factory_obj.html#aaebb437ff1300951ba83071c7a998725", null ],
       [ "getType", "class_ogre_1_1_factory_obj.html#ae46bdfaa9ea186c7545c533572b62f8f", null ],
       [ "createInstance", "class_ogre_1_1_factory_obj.html#a7ea883a3d14824e1b75659c7495d271a", null ],
@@ -532,7 +532,7 @@ var group___general =
       [ "Serializer", "class_ogre_1_1_serializer.html#a3268ab522d56e98d88b604255b0f43d4", null ],
       [ "~Serializer", "class_ogre_1_1_serializer.html#a6e038a802f8d1f293e73b4d98f6e297d", null ]
     ] ],
-    [ "Ogre::SharedPtr< T >", "class_ogre_1_1_shared_ptr.html", [
+    [ "Ogre::SharedPtr&lt; T &gt;", "class_ogre_1_1_shared_ptr.html", [
       [ "SharedPtr", "class_ogre_1_1_shared_ptr.html#a813261f2607ae4a407b90c903fd6f030", null ],
       [ "SharedPtr", "class_ogre_1_1_shared_ptr.html#a6dc65b8171394624d1bb43fd9d54a8f6", null ],
       [ "SharedPtr", "class_ogre_1_1_shared_ptr.html#a119d4d068679964c64a79b2867dd5009", null ],
@@ -551,15 +551,15 @@ var group___general =
       [ "isNull", "class_ogre_1_1_shared_ptr.html#a9ea46224e54b579a56ea769136e12e01", null ],
       [ "setNull", "class_ogre_1_1_shared_ptr.html#a0102c9ce0678ec964b26e47b8a5310d1", null ]
     ] ],
-    [ "Ogre::SimpleParamCommand< _Class, Param, getter, setter >", "class_ogre_1_1_simple_param_command.html", [
+    [ "Ogre::SimpleParamCommand&lt; _Class, Param, getter, setter &gt;", "class_ogre_1_1_simple_param_command.html", [
       [ "doGet", "class_ogre_1_1_simple_param_command.html#a29ff02942b19b51153abd53a878e244a", null ],
       [ "doSet", "class_ogre_1_1_simple_param_command.html#a9727fda386f95b2bb29bf41c553bd944", null ]
     ] ],
-    [ "Ogre::SimpleParamCommand< _Class, const String &, getter, setter >", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", [
+    [ "Ogre::SimpleParamCommand&lt; _Class, const String &amp;, getter, setter &gt;", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html", [
       [ "doGet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#aad3aa9c19d5ee9d99cc680ba84162082", null ],
       [ "doSet", "class_ogre_1_1_simple_param_command_3_01___class_00_01const_01_string_01_6_00_01getter_00_01setter_01_4.html#a5f19051871ee808c8efad85a47e80521", null ]
     ] ],
-    [ "Ogre::Singleton< T >", "class_ogre_1_1_singleton.html", [
+    [ "Ogre::Singleton&lt; T &gt;", "class_ogre_1_1_singleton.html", [
       [ "Singleton", "class_ogre_1_1_singleton.html#a2b0622a1223ac3a0c6b9c53e787b8d93", null ],
       [ "~Singleton", "class_ogre_1_1_singleton.html#a9bc0518bb06d12629e287149cdcc4b5d", null ],
       [ "getSingleton", "class_ogre_1_1_singleton.html#af06b4241e5a935d89bebcc716c329f2a", null ],
@@ -655,7 +655,7 @@ var group___general =
       [ "format", "class_ogre_1_1_string_util.html#ac01104ece71cfc3f7a951ed031518125", null ],
       [ "BLANK", "class_ogre_1_1_string_util.html#a853acbc843b0127ecf069c6aef70baed", null ]
     ] ],
-    [ "Ogre::TRect< T >", "struct_ogre_1_1_t_rect.html", [
+    [ "Ogre::TRect&lt; T &gt;", "struct_ogre_1_1_t_rect.html", [
       [ "TRect", "struct_ogre_1_1_t_rect.html#a91f3cea3b1851f9b4b9004df78822678", null ],
       [ "TRect", "struct_ogre_1_1_t_rect.html#a79e390fbd62e5a819207d6aee0789ab5", null ],
       [ "TRect", "struct_ogre_1_1_t_rect.html#aaf94532ce0aaa722ff067be346fa15b1", null ],
