@@ -1,31 +1,56 @@
 var NAVTREEINDEX19 =
 {
+"class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[5,1,2,1,1],
+"class_ogre_1_1_lod_config_serializer.html":[6,0,1,244],
+"class_ogre_1_1_lod_config_serializer.html":[7,0,0,244],
+"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[6,0,1,244,2],
+"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[7,0,0,244,2],
+"class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[6,0,1,244,4],
+"class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[7,0,0,244,4],
+"class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[6,0,1,244,0],
+"class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[7,0,0,244,0],
+"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[6,0,1,244,1],
+"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[7,0,0,244,1],
+"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[6,0,1,244,3],
+"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[7,0,0,244,3],
+"class_ogre_1_1_lod_input_provider.html":[6,0,1,246],
+"class_ogre_1_1_lod_input_provider.html":[7,0,0,246],
+"class_ogre_1_1_lod_input_provider.html#a1b5411e968e40e5e645871eaeba90270":[6,0,1,246,1],
+"class_ogre_1_1_lod_input_provider.html#a1b5411e968e40e5e645871eaeba90270":[7,0,0,246,1],
+"class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[6,0,1,246,0],
+"class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[7,0,0,246,0],
+"class_ogre_1_1_lod_listener.html":[5,0,4,6],
+"class_ogre_1_1_lod_listener.html#a2690efbb582ca532ad79f4e682730ecd":[5,0,4,6,5],
+"class_ogre_1_1_lod_listener.html#a437b5f300e0f3c38fa581d87e8643784":[5,0,4,6,0],
+"class_ogre_1_1_lod_listener.html#a80c7d710fa6e8119a3294f3f8fd80e46":[5,0,4,6,2],
+"class_ogre_1_1_lod_listener.html#a812c2bf8014cda9f2ef8fa115d4be416":[5,0,4,6,3],
+"class_ogre_1_1_lod_listener.html#a90c2e6ca102b8b43fa2819fc752caf5a":[5,0,4,6,4],
 "class_ogre_1_1_lod_listener.html#aa8bdff391f4865fa7da6f301c350400f":[5,0,4,6,6],
 "class_ogre_1_1_lod_listener.html#afeed906381e75aa6449c95085a207a53":[5,0,4,6,1],
-"class_ogre_1_1_lod_output_provider.html":[6,0,1,248],
-"class_ogre_1_1_lod_output_provider.html":[7,0,0,248],
-"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[6,0,1,248,10],
-"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[7,0,0,248,10],
-"class_ogre_1_1_lod_output_provider.html#a17cccc8d78e808a733c5ef7f0a195b4d":[6,0,1,248,2],
-"class_ogre_1_1_lod_output_provider.html#a17cccc8d78e808a733c5ef7f0a195b4d":[7,0,0,248,2],
-"class_ogre_1_1_lod_output_provider.html#a243c702a028fc9a4459aa65635e75ba1":[6,0,1,248,4],
-"class_ogre_1_1_lod_output_provider.html#a243c702a028fc9a4459aa65635e75ba1":[7,0,0,248,4],
-"class_ogre_1_1_lod_output_provider.html#a25da1d9d3b3c9cee4b0f4002748692b9":[6,0,1,248,8],
-"class_ogre_1_1_lod_output_provider.html#a25da1d9d3b3c9cee4b0f4002748692b9":[7,0,0,248,8],
-"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[6,0,1,248,7],
-"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,248,7],
-"class_ogre_1_1_lod_output_provider.html#a820b37c0f3a7c1486b6c5659e750c879":[6,0,1,248,5],
-"class_ogre_1_1_lod_output_provider.html#a820b37c0f3a7c1486b6c5659e750c879":[7,0,0,248,5],
-"class_ogre_1_1_lod_output_provider.html#a96fd51bd0bc97021b209ae974f3e931d":[6,0,1,248,3],
-"class_ogre_1_1_lod_output_provider.html#a96fd51bd0bc97021b209ae974f3e931d":[7,0,0,248,3],
-"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[6,0,1,248,1],
-"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[7,0,0,248,1],
-"class_ogre_1_1_lod_output_provider.html#ac5072ae91cc4237359876f4a00c65f3a":[6,0,1,248,9],
-"class_ogre_1_1_lod_output_provider.html#ac5072ae91cc4237359876f4a00c65f3a":[7,0,0,248,9],
-"class_ogre_1_1_lod_output_provider.html#ae7ccd75f732798ccd0da8e11a7eec05b":[6,0,1,248,0],
-"class_ogre_1_1_lod_output_provider.html#ae7ccd75f732798ccd0da8e11a7eec05b":[7,0,0,248,0],
-"class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,1,248,6],
-"class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,248,6],
+"class_ogre_1_1_lod_output_provider.html":[6,0,1,249],
+"class_ogre_1_1_lod_output_provider.html":[7,0,0,249],
+"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[6,0,1,249,10],
+"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[7,0,0,249,10],
+"class_ogre_1_1_lod_output_provider.html#a17cccc8d78e808a733c5ef7f0a195b4d":[6,0,1,249,2],
+"class_ogre_1_1_lod_output_provider.html#a17cccc8d78e808a733c5ef7f0a195b4d":[7,0,0,249,2],
+"class_ogre_1_1_lod_output_provider.html#a243c702a028fc9a4459aa65635e75ba1":[6,0,1,249,4],
+"class_ogre_1_1_lod_output_provider.html#a243c702a028fc9a4459aa65635e75ba1":[7,0,0,249,4],
+"class_ogre_1_1_lod_output_provider.html#a25da1d9d3b3c9cee4b0f4002748692b9":[6,0,1,249,8],
+"class_ogre_1_1_lod_output_provider.html#a25da1d9d3b3c9cee4b0f4002748692b9":[7,0,0,249,8],
+"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[6,0,1,249,7],
+"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,249,7],
+"class_ogre_1_1_lod_output_provider.html#a820b37c0f3a7c1486b6c5659e750c879":[6,0,1,249,5],
+"class_ogre_1_1_lod_output_provider.html#a820b37c0f3a7c1486b6c5659e750c879":[7,0,0,249,5],
+"class_ogre_1_1_lod_output_provider.html#a96fd51bd0bc97021b209ae974f3e931d":[6,0,1,249,3],
+"class_ogre_1_1_lod_output_provider.html#a96fd51bd0bc97021b209ae974f3e931d":[7,0,0,249,3],
+"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[6,0,1,249,1],
+"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[7,0,0,249,1],
+"class_ogre_1_1_lod_output_provider.html#ac5072ae91cc4237359876f4a00c65f3a":[6,0,1,249,9],
+"class_ogre_1_1_lod_output_provider.html#ac5072ae91cc4237359876f4a00c65f3a":[7,0,0,249,9],
+"class_ogre_1_1_lod_output_provider.html#ae7ccd75f732798ccd0da8e11a7eec05b":[6,0,1,249,0],
+"class_ogre_1_1_lod_output_provider.html#ae7ccd75f732798ccd0da8e11a7eec05b":[7,0,0,249,0],
+"class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,1,249,6],
+"class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,249,6],
 "class_ogre_1_1_lod_outside_marker.html":[5,1,2,5],
 "class_ogre_1_1_lod_outside_marker.html#a1a23d5f23d72d073dd4bef1869b00372":[5,1,2,5,0],
 "class_ogre_1_1_lod_outside_marker.html#a29dd4b0f1d314671a8eb66a6ae260f93":[5,1,2,5,1],
@@ -57,16 +82,16 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_lod_strategy_manager.html#ae6200e09fc9abc18e90ccba210931f3e":[5,0,4,8,7],
 "class_ogre_1_1_lod_strategy_manager.html#ae69d3723c2841476ea597c585cd2a795":[5,0,4,8,10],
 "class_ogre_1_1_lod_strategy_manager.html#afba001a67e39b1e2537cfe772e6235ec":[5,0,4,8,4],
-"class_ogre_1_1_lod_work_queue_injector_listener.html":[6,0,1,252],
-"class_ogre_1_1_lod_work_queue_injector_listener.html":[7,0,0,252],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#a74c826eff185507f43be26d5fc23194d":[6,0,1,252,2],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#a74c826eff185507f43be26d5fc23194d":[7,0,0,252,2],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#ac090c55e47780f57ab0279fed412b262":[6,0,1,252,1],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#ac090c55e47780f57ab0279fed412b262":[7,0,0,252,1],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#ae8831bf1a3453570de4421a3783db848":[6,0,1,252,3],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#ae8831bf1a3453570de4421a3783db848":[7,0,0,252,3],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#af0b49c4eb3b937cf70d7b588a76536bb":[6,0,1,252,0],
-"class_ogre_1_1_lod_work_queue_injector_listener.html#af0b49c4eb3b937cf70d7b588a76536bb":[7,0,0,252,0],
+"class_ogre_1_1_lod_work_queue_injector_listener.html":[6,0,1,253],
+"class_ogre_1_1_lod_work_queue_injector_listener.html":[7,0,0,253],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#a74c826eff185507f43be26d5fc23194d":[6,0,1,253,2],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#a74c826eff185507f43be26d5fc23194d":[7,0,0,253,2],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#ac090c55e47780f57ab0279fed412b262":[6,0,1,253,1],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#ac090c55e47780f57ab0279fed412b262":[7,0,0,253,1],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#ae8831bf1a3453570de4421a3783db848":[6,0,1,253,3],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#ae8831bf1a3453570de4421a3783db848":[7,0,0,253,3],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#af0b49c4eb3b937cf70d7b588a76536bb":[6,0,1,253,0],
+"class_ogre_1_1_lod_work_queue_injector_listener.html#af0b49c4eb3b937cf70d7b588a76536bb":[7,0,0,253,0],
 "class_ogre_1_1_log.html":[5,0,2,23],
 "class_ogre_1_1_log.html#a149aec94bfb4bcc03c947626f89916ad":[5,0,2,23,1],
 "class_ogre_1_1_log.html#a41ad772d673872b2bbbf87f1f7c52eca":[5,0,2,23,7],
@@ -187,32 +212,32 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_manual_resource_loader.html#a64c9f1f9f2817de97321412c59fabb5a":[5,0,8,15,1],
 "class_ogre_1_1_manual_resource_loader.html#a7b4afd007622d165efbcc362e5566922":[5,0,8,15,2],
 "class_ogre_1_1_manual_resource_loader.html#ae04795ab21e4a46709beb6d521a75c53":[5,0,8,15,3],
-"class_ogre_1_1_map_iterator.html":[6,0,1,259],
-"class_ogre_1_1_map_iterator.html":[7,0,0,259],
-"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[6,0,1,259,0],
-"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[7,0,0,259,0],
-"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[6,0,1,259,1],
-"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[7,0,0,259,1],
-"class_ogre_1_1_map_iterator_wrapper.html":[6,0,1,260],
-"class_ogre_1_1_map_iterator_wrapper.html":[7,0,0,260],
-"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[6,0,1,260,5],
-"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[7,0,0,260,5],
-"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[6,0,1,260,8],
-"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[7,0,0,260,8],
-"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[6,0,1,260,4],
-"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[7,0,0,260,4],
-"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[6,0,1,260,0],
-"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[7,0,0,260,0],
-"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,1,260,2],
-"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,260,2],
-"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[6,0,1,260,7],
-"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,260,7],
-"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,1,260,6],
-"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,260,6],
-"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,1,260,3],
-"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,260,3],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,1,260,1],
-"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,260,1],
+"class_ogre_1_1_map_iterator.html":[6,0,1,260],
+"class_ogre_1_1_map_iterator.html":[7,0,0,260],
+"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[6,0,1,260,0],
+"class_ogre_1_1_map_iterator.html#a69f5d04fa24319d698b69da3da118d36":[7,0,0,260,0],
+"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[6,0,1,260,1],
+"class_ogre_1_1_map_iterator.html#acae97fd0a5ae45d19b51ef4bd046d516":[7,0,0,260,1],
+"class_ogre_1_1_map_iterator_wrapper.html":[6,0,1,261],
+"class_ogre_1_1_map_iterator_wrapper.html":[7,0,0,261],
+"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[6,0,1,261,5],
+"class_ogre_1_1_map_iterator_wrapper.html#a1ab2dc537e2e04c6163f5901b791e9fc":[7,0,0,261,5],
+"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[6,0,1,261,8],
+"class_ogre_1_1_map_iterator_wrapper.html#a2bef2d340ae00274856261b3ad3dcdbc":[7,0,0,261,8],
+"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[6,0,1,261,4],
+"class_ogre_1_1_map_iterator_wrapper.html#a3ae82a852790d4ccf429958639672765":[7,0,0,261,4],
+"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[6,0,1,261,0],
+"class_ogre_1_1_map_iterator_wrapper.html#a649a4446fa5696bd95ed4ec5c3c9208a":[7,0,0,261,0],
+"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[6,0,1,261,2],
+"class_ogre_1_1_map_iterator_wrapper.html#a9853756cc9d465e44272d69643d2c5ed":[7,0,0,261,2],
+"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[6,0,1,261,7],
+"class_ogre_1_1_map_iterator_wrapper.html#aad79b04aa34d0901590bc5229b196c92":[7,0,0,261,7],
+"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[6,0,1,261,6],
+"class_ogre_1_1_map_iterator_wrapper.html#aae9d34883001f20e7b977fcf2bbaa38c":[7,0,0,261,6],
+"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[6,0,1,261,3],
+"class_ogre_1_1_map_iterator_wrapper.html#aba5a8ef400da4e0338f9b257727e9377":[7,0,0,261,3],
+"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[6,0,1,261,1],
+"class_ogre_1_1_map_iterator_wrapper.html#aeec13b7cd63fbc88d204df876a48393c":[7,0,0,261,1],
 "class_ogre_1_1_material.html":[5,0,5,15],
 "class_ogre_1_1_material.html#a008c264b3fa918677120621d6a112f99":[5,0,5,15,38],
 "class_ogre_1_1_material.html#a00967b56ec980480ba12dc6002462c3b":[5,0,5,15,7],
@@ -224,30 +249,5 @@ var NAVTREEINDEX19 =
 "class_ogre_1_1_material.html#a1158a82d9399448666ea415d5f9a10a9":[5,0,5,15,17],
 "class_ogre_1_1_material.html#a145badc7cadec0958241a47b6037b3e6":[5,0,5,15,56],
 "class_ogre_1_1_material.html#a1f51926064eaa39f9d85393b41bb8870":[5,0,5,15,30],
-"class_ogre_1_1_material.html#a2424a948e95a581d1b7de87ea14e7131":[5,0,5,15,52],
-"class_ogre_1_1_material.html#a255bc92a45a8740b388a2b3f0691ee67":[5,0,5,15,29],
-"class_ogre_1_1_material.html#a27911290eaa7990dea483f62d27c9285":[5,0,5,15,40],
-"class_ogre_1_1_material.html#a284464b0561a6f2915f04b0245b987f0":[5,0,5,15,71],
-"class_ogre_1_1_material.html#a2b00231e68df74a029421e1511ae97d6":[5,0,5,15,18],
-"class_ogre_1_1_material.html#a2e2118319d3d7cb1610869c33ab766eb":[5,0,5,15,5],
-"class_ogre_1_1_material.html#a329e758eca8bedadf01edc49f29c5b2e":[5,0,5,15,59],
-"class_ogre_1_1_material.html#a361a7b4a9a597fe2022dae3ccdc24978":[5,0,5,15,22],
-"class_ogre_1_1_material.html#a44413ef81066bc9a44e29361749a0f6e":[5,0,5,15,41],
-"class_ogre_1_1_material.html#a4969168248bff6aea70eafcf75497689":[5,0,5,15,3],
-"class_ogre_1_1_material.html#a4ecddf1c4c7a0ac32e164637cb4944c8":[5,0,5,15,13],
-"class_ogre_1_1_material.html#a4fd57dfc14f62db4444af99d790dc3d0":[5,0,5,15,20],
-"class_ogre_1_1_material.html#a5552baf6c922eb48a981f7c51aadc5e2":[5,0,5,15,10],
-"class_ogre_1_1_material.html#a5e6e5526611a5f10203225e4d2f86d0c":[5,0,5,15,43],
-"class_ogre_1_1_material.html#a625d27ef43d359a6b4f2dc58a363af95":[5,0,5,15,34],
-"class_ogre_1_1_material.html#a66ab9a0f0ef89e66a0f0e0349433af39":[5,0,5,15,58],
-"class_ogre_1_1_material.html#a67d79bf335a4f3a9ed2bc9d70b2e7994":[5,0,5,15,61],
-"class_ogre_1_1_material.html#a72e01ffc38eca515f70387c2b1a72c4c":[5,0,5,15,50],
-"class_ogre_1_1_material.html#a73e00de2aaa067ae659c56c886337b36":[5,0,5,15,2],
-"class_ogre_1_1_material.html#a758ce629d7d709a7038ede19d21f59cf":[5,0,5,15,48],
-"class_ogre_1_1_material.html#a75f43a20ac158be5187facacdb4b1f70":[5,0,5,15,9],
-"class_ogre_1_1_material.html#a7b73a4bace2cde1c32b0d4fdea407ff4":[5,0,5,15,0],
-"class_ogre_1_1_material.html#a7fc8d8c84177939161df8fe239695eeb":[5,0,5,15,23],
-"class_ogre_1_1_material.html#a8809a6d4f0e4e6380aee7f0e34e5d2cf":[5,0,5,15,68],
-"class_ogre_1_1_material.html#a8937a20eafba0997f7a6889fd6a188e4":[5,0,5,15,46],
-"class_ogre_1_1_material.html#a8a81c60f958b0f3615c8690583c10d52":[5,0,5,15,16]
+"class_ogre_1_1_material.html#a2424a948e95a581d1b7de87ea14e7131":[5,0,5,15,52]
 };
