@@ -1,5 +1,29 @@
 var NAVTREEINDEX25 =
 {
+"class_ogre_1_1_p_c_z_frustum.html#a80703cbea15bbe558c6ef9bec77cb592":[5,2,9,3,9],
+"class_ogre_1_1_p_c_z_frustum.html#a84738d07b1001be10a5628870c55ae55":[5,2,9,3,15],
+"class_ogre_1_1_p_c_z_frustum.html#a8a7ebf11b58dea6d550e107d42067436":[5,2,9,3,1],
+"class_ogre_1_1_p_c_z_frustum.html#aa2f491448874e2c406d7c6eea2acb87e":[5,2,9,3,2],
+"class_ogre_1_1_p_c_z_frustum.html#aa7bcb920cac2f626ae456b529286eab2":[5,2,9,3,5],
+"class_ogre_1_1_p_c_z_frustum.html#abc51c9cb3798768f1c1011411be217e7":[5,2,9,3,3],
+"class_ogre_1_1_p_c_z_frustum.html#accbb31c158eb7f299e6a364d9e1f81c5":[5,2,9,3,7],
+"class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0":[5,2,9,3,0],
+"class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0a80f7e32f2ff9beaa89ca2f2a3005f784":[5,2,9,3,0,1],
+"class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0abd7c5a5255321386e7068e5da5f1e497":[5,2,9,3,0,0],
+"class_ogre_1_1_p_c_z_frustum.html#ad16ed839fe1810504c262e45b4e81ec0ac8d449ff26f6e8000ec3f5571d13b66f":[5,2,9,3,0,2],
+"class_ogre_1_1_p_c_z_frustum.html#ad89a86104eae899243a20ac5853bed05":[5,2,9,3,14],
+"class_ogre_1_1_p_c_z_frustum.html#addbc896267412ef5876bdf7dc842abee":[5,2,9,3,10],
+"class_ogre_1_1_p_c_z_frustum.html#aecf0bf5650137366f3c5b9cf7ae6ff24":[5,2,9,3,17],
+"class_ogre_1_1_p_c_z_frustum.html#afe12561a64afee6006c19ca1f6b763e6":[5,2,9,3,4],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html":[6,0,1,343],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html":[7,0,0,343],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#a1b33d34a14964847c704f419184cc89d":[6,0,1,343,2],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#a1b33d34a14964847c704f419184cc89d":[7,0,0,343,2],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#a30748b15767886b23f9ce5b1b7ea0b1e":[6,0,1,343,1],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#a30748b15767886b23f9ce5b1b7ea0b1e":[7,0,0,343,1],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#aa5d028afad52a57b0a04e5a00e4187cd":[6,0,1,343,0],
+"class_ogre_1_1_p_c_z_intersection_scene_query.html#aa5d028afad52a57b0a04e5a00e4187cd":[7,0,0,343,0],
+"class_ogre_1_1_p_c_z_light.html":[5,2,9,4],
 "class_ogre_1_1_p_c_z_light.html#a017e849f6d4adcffba153f80d9c8bbe6":[5,2,9,4,12],
 "class_ogre_1_1_p_c_z_light.html#a0d7d0bcc9aad97228ef7e40e41f7c7b6":[5,2,9,4,5],
 "class_ogre_1_1_p_c_z_light.html#a2565a8e8a9ef516800ab6514dce61055":[5,2,9,4,13],
@@ -19,44 +43,44 @@ var NAVTREEINDEX25 =
 "class_ogre_1_1_p_c_z_light_factory.html#a2c58d971af884e88775f8cf46fe7e75a":[5,2,9,5,0],
 "class_ogre_1_1_p_c_z_light_factory.html#a7512e363b4db3fd110fe4307fd5c16e8":[5,2,9,5,1],
 "class_ogre_1_1_p_c_z_light_factory.html#ae943f1e7527419df075c47299e9c99cd":[5,2,9,5,3],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html":[6,0,1,348],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html":[7,0,0,348],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a30cee0d4a59b1bf4536b12049b925904":[6,0,1,348,0],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a30cee0d4a59b1bf4536b12049b925904":[7,0,0,348,0],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a998599724191c862dab1648a6a8f574c":[6,0,1,348,3],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a998599724191c862dab1648a6a8f574c":[7,0,0,348,3],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#ae927843b56e5c56452b4e2b6a47bca92":[6,0,1,348,1],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#ae927843b56e5c56452b4e2b6a47bca92":[7,0,0,348,1],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#aeb53050a00ef9d5faeb050bf53a40c92":[6,0,1,348,2],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#aeb53050a00ef9d5faeb050bf53a40c92":[7,0,0,348,2],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#af4da1b3b64c2eaa24074bf4b17b1c69c":[6,0,1,348,4],
-"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#af4da1b3b64c2eaa24074bf4b17b1c69c":[7,0,0,348,4],
-"class_ogre_1_1_p_c_z_plugin.html":[6,0,1,349],
-"class_ogre_1_1_p_c_z_plugin.html":[7,0,0,349],
-"class_ogre_1_1_p_c_z_plugin.html#a0bb7e9c8b863a95ca22549adca5bf4ea":[6,0,1,349,5],
-"class_ogre_1_1_p_c_z_plugin.html#a0bb7e9c8b863a95ca22549adca5bf4ea":[7,0,0,349,5],
-"class_ogre_1_1_p_c_z_plugin.html#a2062313a8dfa53e1536dec38cd268c66":[6,0,1,349,0],
-"class_ogre_1_1_p_c_z_plugin.html#a2062313a8dfa53e1536dec38cd268c66":[7,0,0,349,0],
-"class_ogre_1_1_p_c_z_plugin.html#a293e8c0b2a24e8f0aae9c0e0d4cddd99":[6,0,1,349,4],
-"class_ogre_1_1_p_c_z_plugin.html#a293e8c0b2a24e8f0aae9c0e0d4cddd99":[7,0,0,349,4],
-"class_ogre_1_1_p_c_z_plugin.html#a322f1153868261754afa5aa9c353db34":[6,0,1,349,1],
-"class_ogre_1_1_p_c_z_plugin.html#a322f1153868261754afa5aa9c353db34":[7,0,0,349,1],
-"class_ogre_1_1_p_c_z_plugin.html#a9ea85c25573faae530d8c0c6b0e8dbea":[6,0,1,349,2],
-"class_ogre_1_1_p_c_z_plugin.html#a9ea85c25573faae530d8c0c6b0e8dbea":[7,0,0,349,2],
-"class_ogre_1_1_p_c_z_plugin.html#ada0ba1ab7d1c98ce6a2b051d3b02def5":[6,0,1,349,3],
-"class_ogre_1_1_p_c_z_plugin.html#ada0ba1ab7d1c98ce6a2b051d3b02def5":[7,0,0,349,3],
-"class_ogre_1_1_p_c_z_ray_scene_query.html":[6,0,1,350],
-"class_ogre_1_1_p_c_z_ray_scene_query.html":[7,0,0,350],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a2309be79293df20ef093379939e95b60":[6,0,1,350,0],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a2309be79293df20ef093379939e95b60":[7,0,0,350,0],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a356aedf2e4141f1671355b93a0c4417d":[6,0,1,350,1],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a356aedf2e4141f1671355b93a0c4417d":[7,0,0,350,1],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a714850125015e22612ed3f9fd1265d0e":[6,0,1,350,2],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#a714850125015e22612ed3f9fd1265d0e":[7,0,0,350,2],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#acd41da34e7f4c130891ef9b656139c1d":[6,0,1,350,4],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#acd41da34e7f4c130891ef9b656139c1d":[7,0,0,350,4],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#add0698bb716cba1f309414686f0420d8":[6,0,1,350,3],
-"class_ogre_1_1_p_c_z_ray_scene_query.html#add0698bb716cba1f309414686f0420d8":[7,0,0,350,3],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html":[6,0,1,349],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html":[7,0,0,349],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a30cee0d4a59b1bf4536b12049b925904":[6,0,1,349,0],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a30cee0d4a59b1bf4536b12049b925904":[7,0,0,349,0],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a998599724191c862dab1648a6a8f574c":[6,0,1,349,3],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#a998599724191c862dab1648a6a8f574c":[7,0,0,349,3],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#ae927843b56e5c56452b4e2b6a47bca92":[6,0,1,349,1],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#ae927843b56e5c56452b4e2b6a47bca92":[7,0,0,349,1],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#aeb53050a00ef9d5faeb050bf53a40c92":[6,0,1,349,2],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#aeb53050a00ef9d5faeb050bf53a40c92":[7,0,0,349,2],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#af4da1b3b64c2eaa24074bf4b17b1c69c":[6,0,1,349,4],
+"class_ogre_1_1_p_c_z_plane_bounded_volume_list_scene_query.html#af4da1b3b64c2eaa24074bf4b17b1c69c":[7,0,0,349,4],
+"class_ogre_1_1_p_c_z_plugin.html":[6,0,1,350],
+"class_ogre_1_1_p_c_z_plugin.html":[7,0,0,350],
+"class_ogre_1_1_p_c_z_plugin.html#a0bb7e9c8b863a95ca22549adca5bf4ea":[6,0,1,350,5],
+"class_ogre_1_1_p_c_z_plugin.html#a0bb7e9c8b863a95ca22549adca5bf4ea":[7,0,0,350,5],
+"class_ogre_1_1_p_c_z_plugin.html#a2062313a8dfa53e1536dec38cd268c66":[6,0,1,350,0],
+"class_ogre_1_1_p_c_z_plugin.html#a2062313a8dfa53e1536dec38cd268c66":[7,0,0,350,0],
+"class_ogre_1_1_p_c_z_plugin.html#a293e8c0b2a24e8f0aae9c0e0d4cddd99":[6,0,1,350,4],
+"class_ogre_1_1_p_c_z_plugin.html#a293e8c0b2a24e8f0aae9c0e0d4cddd99":[7,0,0,350,4],
+"class_ogre_1_1_p_c_z_plugin.html#a322f1153868261754afa5aa9c353db34":[6,0,1,350,1],
+"class_ogre_1_1_p_c_z_plugin.html#a322f1153868261754afa5aa9c353db34":[7,0,0,350,1],
+"class_ogre_1_1_p_c_z_plugin.html#a9ea85c25573faae530d8c0c6b0e8dbea":[6,0,1,350,2],
+"class_ogre_1_1_p_c_z_plugin.html#a9ea85c25573faae530d8c0c6b0e8dbea":[7,0,0,350,2],
+"class_ogre_1_1_p_c_z_plugin.html#ada0ba1ab7d1c98ce6a2b051d3b02def5":[6,0,1,350,3],
+"class_ogre_1_1_p_c_z_plugin.html#ada0ba1ab7d1c98ce6a2b051d3b02def5":[7,0,0,350,3],
+"class_ogre_1_1_p_c_z_ray_scene_query.html":[6,0,1,351],
+"class_ogre_1_1_p_c_z_ray_scene_query.html":[7,0,0,351],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a2309be79293df20ef093379939e95b60":[6,0,1,351,0],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a2309be79293df20ef093379939e95b60":[7,0,0,351,0],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a356aedf2e4141f1671355b93a0c4417d":[6,0,1,351,1],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a356aedf2e4141f1671355b93a0c4417d":[7,0,0,351,1],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a714850125015e22612ed3f9fd1265d0e":[6,0,1,351,2],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#a714850125015e22612ed3f9fd1265d0e":[7,0,0,351,2],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#acd41da34e7f4c130891ef9b656139c1d":[6,0,1,351,4],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#acd41da34e7f4c130891ef9b656139c1d":[7,0,0,351,4],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#add0698bb716cba1f309414686f0420d8":[6,0,1,351,3],
+"class_ogre_1_1_p_c_z_ray_scene_query.html#add0698bb716cba1f309414686f0420d8":[7,0,0,351,3],
 "class_ogre_1_1_p_c_z_scene_manager.html":[5,2,9,7],
 "class_ogre_1_1_p_c_z_scene_manager.html#a0d0e8fece331960d1d81adb188797c52":[5,2,9,7,46],
 "class_ogre_1_1_p_c_z_scene_manager.html#a0f46ad3758026a3cefff77b8313fb084":[5,2,9,7,66],
@@ -164,18 +188,18 @@ var NAVTREEINDEX25 =
 "class_ogre_1_1_p_c_z_scene_node.html#ad7f4d6b922c7e24cb03dae8c8c967c28":[5,2,9,9,26],
 "class_ogre_1_1_p_c_z_scene_node.html#adba366cb94952a38d89233b1fe2659c4":[5,2,9,9,18],
 "class_ogre_1_1_p_c_z_scene_node.html#afdf56660f1aee5a3e0104ad40b059e34":[5,2,9,9,3],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html":[6,0,1,354],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html":[7,0,0,354],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#a5b5f4497b62078d4914a0bf8b10de305":[6,0,1,354,2],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#a5b5f4497b62078d4914a0bf8b10de305":[7,0,0,354,2],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#aa91b0e3995217a3c999a8794b33465ca":[6,0,1,354,1],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#aa91b0e3995217a3c999a8794b33465ca":[7,0,0,354,1],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#ab59bf5a2ee134e50043150008d302f05":[6,0,1,354,3],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#ab59bf5a2ee134e50043150008d302f05":[7,0,0,354,3],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#abcf3c9e7da025e457e3dc23a443b3a44":[6,0,1,354,0],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#abcf3c9e7da025e457e3dc23a443b3a44":[7,0,0,354,0],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#afbe730607ac57b89ff93c1834bb6926c":[6,0,1,354,4],
-"class_ogre_1_1_p_c_z_sphere_scene_query.html#afbe730607ac57b89ff93c1834bb6926c":[7,0,0,354,4],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html":[6,0,1,355],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html":[7,0,0,355],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#a5b5f4497b62078d4914a0bf8b10de305":[6,0,1,355,2],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#a5b5f4497b62078d4914a0bf8b10de305":[7,0,0,355,2],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#aa91b0e3995217a3c999a8794b33465ca":[6,0,1,355,1],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#aa91b0e3995217a3c999a8794b33465ca":[7,0,0,355,1],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#ab59bf5a2ee134e50043150008d302f05":[6,0,1,355,3],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#ab59bf5a2ee134e50043150008d302f05":[7,0,0,355,3],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#abcf3c9e7da025e457e3dc23a443b3a44":[6,0,1,355,0],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#abcf3c9e7da025e457e3dc23a443b3a44":[7,0,0,355,0],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#afbe730607ac57b89ff93c1834bb6926c":[6,0,1,355,4],
+"class_ogre_1_1_p_c_z_sphere_scene_query.html#afbe730607ac57b89ff93c1834bb6926c":[7,0,0,355,4],
 "class_ogre_1_1_p_c_zone.html":[5,2,9,6],
 "class_ogre_1_1_p_c_zone.html#a053576e1866ba02ec96b51b1f46854ee":[5,2,9,6,26],
 "class_ogre_1_1_p_c_zone.html#a127fceccd44fb4c49a503edceb054623":[5,2,9,6,35],
@@ -225,29 +249,5 @@ var NAVTREEINDEX25 =
 "class_ogre_1_1_p_c_zone.html#ae9210b537407fadb23e46c30fd884d9a":[5,2,9,6,17],
 "class_ogre_1_1_p_c_zone.html#aef88f09e45e94145c19932a77f491dfe":[5,2,9,6,25],
 "class_ogre_1_1_p_c_zone.html#afffceda4722bddf44acdab10cd95ad52":[5,2,9,6,23],
-"class_ogre_1_1_p_c_zone_factory.html":[6,0,1,346],
-"class_ogre_1_1_p_c_zone_factory.html":[7,0,0,346],
-"class_ogre_1_1_p_c_zone_factory.html#a0a69be4d18453ee9c821c391cf62ab9a":[6,0,1,346,3],
-"class_ogre_1_1_p_c_zone_factory.html#a0a69be4d18453ee9c821c391cf62ab9a":[7,0,0,346,3],
-"class_ogre_1_1_p_c_zone_factory.html#a200b3058b74b030d9ee5f8431c83c661":[6,0,1,346,0],
-"class_ogre_1_1_p_c_zone_factory.html#a200b3058b74b030d9ee5f8431c83c661":[7,0,0,346,0],
-"class_ogre_1_1_p_c_zone_factory.html#a3dcc6635bc0ee138a721c7f983180a44":[6,0,1,346,4],
-"class_ogre_1_1_p_c_zone_factory.html#a3dcc6635bc0ee138a721c7f983180a44":[7,0,0,346,4],
-"class_ogre_1_1_p_c_zone_factory.html#a6e44aa6deec83443fc10559cf29b89e2":[6,0,1,346,1],
-"class_ogre_1_1_p_c_zone_factory.html#a6e44aa6deec83443fc10559cf29b89e2":[7,0,0,346,1],
-"class_ogre_1_1_p_c_zone_factory.html#ac511693cfa22fe52fd7b22e5b370191d":[6,0,1,346,2],
-"class_ogre_1_1_p_c_zone_factory.html#ac511693cfa22fe52fd7b22e5b370191d":[7,0,0,346,2],
-"class_ogre_1_1_p_c_zone_factory.html#afb863ab16a3cfebe70c9d4abb629b7e2":[6,0,1,346,5],
-"class_ogre_1_1_p_c_zone_factory.html#afb863ab16a3cfebe70c9d4abb629b7e2":[7,0,0,346,5],
-"class_ogre_1_1_p_c_zone_factory_manager.html":[6,0,1,347],
-"class_ogre_1_1_p_c_zone_factory_manager.html":[7,0,0,347],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a1d40a94c55b6d25791e9b4e43ee054ec":[6,0,1,347,9],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a1d40a94c55b6d25791e9b4e43ee054ec":[7,0,0,347,9],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a3473f9139db171f64c58b468b0bb48fb":[6,0,1,347,1],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a3473f9139db171f64c58b468b0bb48fb":[7,0,0,347,1],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a36d332d0ffb24b6301d12b8bdd284100":[6,0,1,347,8],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a36d332d0ffb24b6301d12b8bdd284100":[7,0,0,347,8],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a467b7946ab23580257f243c91f9304a9":[6,0,1,347,6],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a467b7946ab23580257f243c91f9304a9":[7,0,0,347,6],
-"class_ogre_1_1_p_c_zone_factory_manager.html#a4edd1bb201598e8c70a022f98afaf00d":[6,0,1,347,0]
+"class_ogre_1_1_p_c_zone_factory.html":[6,0,1,347]
 };
