@@ -49,7 +49,7 @@ var searchData=
   ['point_5fsprites_46',['point_sprites',['../_material-_scripts.html#autotoc_md151',1,'']]],
   ['polygon_5fmode_47',['polygon_mode',['../_material-_scripts.html#autotoc_md144',1,'']]],
   ['polygon_5fmode_5foverrideable_48',['polygon_mode_overrideable',['../_material-_scripts.html#autotoc_md145',1,'']]],
-  ['portals_49',['CREATING PORTALS',['..//build/ogre/src/ogre-14.4.1/PlugIns/PCZSceneManager/docs/readme.md#autotoc_md4',1,'']]],
+  ['portals_49',['CREATING PORTALS',['../dir_67ea8a25251f25c005532ef7e5f68f3d.html#autotoc_md4',1,'']]],
   ['pose_20animation_50',['Pose Animation',['../_animation.html#Pose-Animation',1,'']]],
   ['pose_20animation_20in_20vertex_20programs_51',['Pose Animation in Vertex Programs',['../_high-level-_programs.html#Pose-Animation-in-Vertex-Programs',1,'']]],
   ['position_52',['position',['../_particle-_scripts.html#autotoc_md231',1,'']]],
