@@ -74,6 +74,7 @@ var tutorials =
         [ "Defining a terrain chunk", "tut__terrain_sky_fog.html#bt3TerrainChunk", null ],
         [ "Loading a heightmap", "tut__terrain_sky_fog.html#bt3Heightmap", null ],
         [ "Height based blending", "tut__terrain_sky_fog.html#bt3Blendmap", null ],
+        [ "Storing changes", "tut__terrain_sky_fog.html#bt3StoringChanges", null ],
         [ "Loading Label", "tut__terrain_sky_fog.html#bt3LoadingLabel", null ]
       ] ],
       [ "Simulating a sky", "tut__terrain_sky_fog.html#bt3sky", [
@@ -86,8 +87,10 @@ var tutorials =
       ] ],
       [ "Conclusion", "tut__terrain_sky_fog.html#conclusion3", null ]
     ] ],
-    [ "Working with NumPy", "working-with-numpy.html", [
-      [ "Background Threads", "working-with-numpy.html#python-background-threads", null ]
+    [ "Working with Python", "working-with-numpy.html", [
+      [ "HighPy: A High-Level API", "working-with-numpy.html#python-highpy", null ],
+      [ "NumPy Interoperability", "working-with-numpy.html#python-numpy", null ],
+      [ "Running Background Threads", "working-with-numpy.html#python-background-threads", null ]
     ] ],
     [ "Trays GUI System", "trays.html", [
       [ "Trays", "trays.html#trays-1", null ],
